Learn R Programming

EMA (version 1.4.4)

clustering.kmeans: Kmeans and hierarchical clustering

Description

Kmeans clustering to summarize the genes information and hierarchical clustering on the kmeans' groups

Usage

clustering.kmeans(data, N = 100, iter.max = 20, title = "Kmeans - Hierarchical Clustering", dist.s = "pearson", dist.g = "pearsonabs", method = "ward")

Arguments

data
Expression matrix, genes on rows and samples on columns
N
The number of a priori clusters for the kmeans
iter.max
The maximum number of iterations allowed for the kmeans clustering
title
The plot title
dist.s
The distance used for the sample clustering
dist.g
The distance used for the genes clustering
method
The linkage used for both clusterings

Value

A list with the kmeans object and the two hierarchical clusterings.
c.km
An object of class 'kmeans'.
c.sample
An object of class 'agnes'. The hierarchical clustering on samples
c.kcenters
An object of class 'agnes'. The hierarchical clustering on the kmeans centers

Details

The goal of this analysis is to first summarizes the genes information using the kmeans clustering. Then, a two-ways clustering is performed using the center of each kmean groups, and all the samples.

See Also

kmeans,agnes

Examples

Run this code
data(marty)
##Example on 100 genes for 5 classes
clustering.kmeans(marty[1:100,], N=5)

Run the code above in your browser using DataLab