Expression matrix, genes on rows and samples on columns
N
The number of a priori clusters for the kmeans
iter.max
The maximum number of iterations allowed for the kmeans clustering
title
The plot title
dist.s
The distance used for the sample clustering
dist.g
The distance used for the genes clustering
method
The linkage used for both clusterings
Value
A list with the kmeans object and the two hierarchical clusterings.
c.kmAn object of class 'kmeans'.
c.sampleAn object of class 'agnes'. The hierarchical clustering on samples
c.kcentersAn object of class 'agnes'. The hierarchical clustering on the kmeans centers
Details
The goal of this analysis is to first summarizes the genes information using the kmeans clustering. Then, a two-ways clustering is performed using the center of each kmean groups, and all the samples.